@@ -9,7 +9,7 @@ return {
     group 'BlockQuote' {
       test('access content via property `content`', function ()
         local elem = BlockQuote{'word'}
-        assert.are_same(elem.content, {Plain 'word'})
+        assert.are_equal(elem.content, Blocks{Plain 'word'})
         assert.are_equal(type(elem.content), 'table')
 
         elem.content = {
@@ -29,16 +29,47 @@ return {
       test('access items via property `content`', function ()
         local para = Para 'one'
         local blist = BulletList{{para}}
-        assert.are_same({{para}}, blist.content)
+        assert.are_equal(List{Blocks{para}}, blist.content)
+      end),
+      test('property `content` is a list of Block lists', function ()
+        local items = List{Blocks{Plain 'item 1'}, Blocks{Plain 'item 2'}}
+        local blist = BulletList{}
+        blist.content = items
+        assert.are_equal(items, blist:clone().content)
       end),
       test('property `content` uses fuzzy marshalling', function ()
-        local old = Plain 'old'
         local new = Plain 'new'
-        local blist = BulletList{{old}}
+        local blist = BulletList{{Plain 'old'}}
         blist.content = {{new}}
-        assert.are_same({{new}}, blist:clone().content)
+        assert.are_equal(List{Blocks{new}}, blist:clone().content)
         blist.content = new
-        assert.are_same({{new}}, blist:clone().content)
+        assert.are_equal(List{Blocks{new}}, blist:clone().content)
+      end),
+      test('property `content` prioritizes lists', function ()
+        local blist = BulletList{}
+        local one, two = Para 'one', Plain 'two'
+        blist.content = {one, two}
+        assert.are_equal(
+          List{Blocks{one}, Blocks{two}},
+          blist:clone().content
+        )
+      end),
+      test('behavior is consistent with constructor', function ()
+        local content = {Para 'one', CodeBlock 'print "Hello"'}
+        local bl1 = BulletList(content)
+        local bl2 = BulletList{}
+        bl2.content = content
+        assert.are_equal(bl1, bl2)
+      end),
+      test('mixing types works', function ()
+             local one = Plain 'one'
+        local two = 'two'
+        local blist = BulletList{}
+        blist.content = {one, two}
+        assert.are_same(
+          List{Blocks{one}, Blocks{Plain(two)}},
+          blist:clone().content
+        )
       end),
     },
     group 'CodeBlock' {
@@ -150,7 +181,7 @@ return {
         local figure = Figure('word', {short='short', long='caption'})
         assert.are_equal(figure.caption.long, Blocks 'caption')
         assert.are_equal(figure.caption.short, Inlines 'short')
-        assert.are_equal(type(figure.caption), 'table')
+        assert.are_equal(type(figure.caption), 'userdata')
 
         figure.caption = {long = 'One day I was...', short = 'My day'}
         assert.are_equal(
@@ -303,15 +334,15 @@ return {
       test('access caption via property `caption`', function ()
         local caption = {long = {Plain 'cap'}}
         local tbl = Table(caption, {}, TableHead(), {}, TableFoot())
-        assert.are_same(tbl.caption, {long = {Plain 'cap'}})
+        assert.are_same(tbl.caption, Caption{Plain 'cap'})
 
         tbl.caption.short = 'brief'
         tbl.caption.long  = {Plain 'extended'}
 
-        local new_caption = {
-          short = 'brief',
-          long = {Plain 'extended'}
-        }
+        local new_caption = Caption(
+          {Plain 'extended'},
+          'brief'
+        )
         assert.are_equal(
           Table(new_caption, {}, TableHead(), {}, TableFoot()),
           tbl
@@ -364,9 +395,9 @@ return {
         )
       end),
       test('caption field accepts list of blocks', function ()
-        local caption = {long = {Plain 'cap'}}
+        local caption = {Plain 'cap'}
         local tbl = Table(caption, {}, TableHead(), {}, TableFoot())
-        assert.are_same(tbl.caption, {long = {Plain 'cap'}})
+        assert.are_same(tbl.caption.long, {Plain 'cap'})
 
         tbl.caption = {Plain 'extended'}
 
@@ -639,5 +670,61 @@ return {
         names
       )
     end),
+  },
+
+  group 'Block marshalling' {
+    test('Inlines are unmarshalled as Plain', function ()
+      assert.are_equal(Blocks{Plain{'a'}}, Blocks{Inlines{Str 'a'}})
+    end),
+
+    group '__toblock metamethod' {
+      test('metamethod __toblock is called when available', function ()
+        local function toblock (t)
+          return CodeBlock(t.code, {id = t.id, class = t.class})
+        end
+        local my_code = setmetatable(
+          {code = 'open access', id='opn'},
+          {__toblock = toblock}
+        )
+        assert.are_equal(
+          Div{CodeBlock('open access', {'opn'})},
+          Div{my_code}
+        )
+      end),
+
+      test("metafield is ignored if it's not a function", function ()
+        local bad_block = setmetatable({'a'}, {__toblock = true})
+        assert.are_equal(
+          Blocks{Plain{'a'}, Plain{'b'}},
+          Blocks{bad_block, {'b'}}
+        )
+      end),
+
+      test("non-Block return values are ignored", function ()
+        local function toblock ()
+          return "not a block"
+        end
+        local bad_block = setmetatable({'a'}, {__toblock = toblock})
+        assert.are_equal(
+          Blocks{Plain{'b'}, Plain{'a'}},
+          Blocks{Plain{'b'}, bad_block}
+        )
+      end),
+
+      test('object with metamethod can be used as singleton list', function ()
+        local function toblock (t)
+          return CodeBlock(t.code, {id = t.id, class = t.class})
+        end
+        local my_code = setmetatable(
+          {code = 'open access', id='opn'},
+          {__toblock = toblock}
+        )
+        assert.are_equal(
+          Div(CodeBlock('open access', {'opn'})),
+          Div(my_code)
+        )
+      end),
+
+    }
   }
 }
